<?php

declare(strict_types=1);

namespace Drupal\ckeditor5_show_block\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\EditorInterface;

/**
 * CKEditor 5 Show Block plugin configuration.
 *
 * @internal
 *   Plugin classes are internal.
 */
class ShowBlockSettings extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['enable_show_block_default'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable show block as default.'),
      '#description' => $this->t('Enable and Disable the show block as default.'),
      '#default_value' => (!empty($this->configuration['enable_show_block_default'])) ? $this->configuration['enable_show_block_default'] : 0,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    $form_state->setValue('enable_show_block_default', $form_state->getValue('enable_show_block_default'));
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['enable_show_block_default'] = $form_state->getValue('enable_show_block_default');
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'enable_show_block_default' => 1
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    return [
      'show_block' => [
        'enable_show_block_default' => $this->configuration['enable_show_block_default'],
      ]
    ];
  }
}
